@@ -15,6 +15,8 @@ from traitlets import HasTraits, Unicode, List, Dict, Bool, default, observe
 from traitlets.config import Config
 from traitlets.utils.importstring import import_item
 from ipython_genutils import py3compat
+from jupyter_core.paths import jupyter_path
+from jupyter_core.utils import ensure_dir_exists
 from jinja2 import (
     TemplateNotFound, Environment, ChoiceLoader, FileSystemLoader, BaseLoader,
     DictLoader
@@ -56,6 +58,7 @@ default_filters = {
         'get_metadata': filters.get_metadata,
         'convert_pandoc': filters.convert_pandoc,
         'json_dumps': json.dumps,
+        'strip_trailing_newline': filters.strip_trailing_newline,
 }
 
 class ExtensionTolerantLoader(BaseLoader):
@@ -184,6 +187,11 @@ class TemplateExporter(Exporter):
         help="Path where the template skeleton files are located.",
     ).tag(affects_environment=True)
 
+    template_data_paths = List(
+        jupyter_path('nbconvert','templates'),
+        help="Path where templates can be installed too."
+    ).tag(affects_environment=True)
+
     #Extension that the template files use.
     template_extension = Unicode(".tpl").tag(config=True, affects_environment=True)
 
@@ -249,7 +257,7 @@ class TemplateExporter(Exporter):
         extra_loaders : list[of Jinja Loaders]
             ordered list of Jinja loader to find templates. Will be tried in order
             before the default FileSystem ones.
-        template : str (optional, kw arg)
+        template_file : str (optional, kw arg)
             Template to use when exporting.
         """
         super(TemplateExporter, self).__init__(config=config, **kw)
@@ -312,6 +320,7 @@ class TemplateExporter(Exporter):
 
         # Top level variables are passed to the template_exporter here.
         output = self.template.render(nb=nb_copy, resources=resources)
+        output = output.lstrip('\r\n')
         return output, resources
 
     def _register_filter(self, environ, name, jinja_filter):
@@ -391,7 +400,15 @@ class TemplateExporter(Exporter):
         """
         here = os.path.dirname(os.path.realpath(__file__))
 
+        additional_paths = self.template_data_paths
+        for path in additional_paths:
+            try:
+                ensure_dir_exists(path, mode=0o700)
+            except OSError:
+                pass
+
         paths = self.template_path + \
+            additional_paths + \
             [os.path.join(here, self.default_template_path),
              os.path.join(here, self.template_skeleton_path)]
 
