@@ -9,11 +9,11 @@ import io
 
 from .base import TestsBase
 from ..postprocessors import PostProcessorBase
+from ..tests.utils import onlyif_cmds_exist
 from nbconvert import nbconvertapp
 from nbconvert.exporters import Exporter
 
 from traitlets.tests.utils import check_help_all_output
-from ipython_genutils.testing import decorators as dec
 from testpath import tempdir
 import pytest
 
@@ -25,6 +25,7 @@ class DummyPost(PostProcessorBase):
     def postprocess(self, filename):
         print("Dummy:%s" % filename)
 
+
 class TestNbConvertApp(TestsBase):
     """Collection of NbConvertApp tests"""
 
@@ -48,7 +49,6 @@ class TestNbConvertApp(TestsBase):
             assert os.path.isfile('notebook1.py')
             assert os.path.isfile('notebook2.py')
 
-
     def test_glob_subdir(self):
         """
         Do search patterns work for subdirectory notebook names?
@@ -117,8 +117,7 @@ class TestNbConvertApp(TestsBase):
                 text = f.read()
             assert text == test_output
 
-    @dec.onlyif_cmds_exist('xelatex')
-    @dec.onlyif_cmds_exist('pandoc')
+    @onlyif_cmds_exist('pandoc', 'xelatex')
     def test_filename_spaces(self):
         """
         Generate PDFs with graphics if notebooks have spaces in the name?
@@ -132,12 +131,10 @@ class TestNbConvertApp(TestsBase):
             )
             assert os.path.isfile('notebook with spaces.pdf')
 
-
-    @dec.onlyif_cmds_exist('xelatex')
-    @dec.onlyif_cmds_exist('pandoc')
+    @onlyif_cmds_exist('pandoc', 'xelatex')
     def test_pdf(self):
         """
-        Check to see if pdfs compile, even if strikethroughs are included. 
+        Check to see if pdfs compile, even if strikethroughs are included.
         """
         with self.create_temp_cwd(['notebook2.ipynb']):
             self.nbconvert('--log-level 0 --to pdf'
@@ -154,7 +151,7 @@ class TestNbConvertApp(TestsBase):
                       '--post nbconvert.tests.test_nbconvertapp.DummyPost')
             self.assertIn('Dummy:notebook1.py', out)
 
-    @dec.onlyif_cmds_exist('pandoc')
+    @onlyif_cmds_exist('pandoc')
     def test_spurious_cr(self):
         """Check for extra CR characters"""
         with self.create_temp_cwd(['notebook2.ipynb']):
@@ -169,7 +166,7 @@ class TestNbConvertApp(TestsBase):
         self.assertEqual(tex.count('\r'), tex.count('\r\n'))
         self.assertEqual(html.count('\r'), html.count('\r\n'))
 
-    @dec.onlyif_cmds_exist('pandoc')
+    @onlyif_cmds_exist('pandoc')
     def test_png_base64_html_ok(self):
         """Is embedded png data well formed in HTML?"""
         with self.create_temp_cwd(['notebook2.ipynb']):
@@ -179,7 +176,7 @@ class TestNbConvertApp(TestsBase):
             with open('notebook2.html') as f:
                 assert "data:image/png;base64,b'" not in f.read()
 
-    @dec.onlyif_cmds_exist('pandoc')
+    @onlyif_cmds_exist('pandoc')
     def test_template(self):
         """
         Do export templates work?
@@ -212,7 +209,6 @@ class TestNbConvertApp(TestsBase):
             assert os.path.isfile('notebook1.py')
             assert os.path.isfile('notebook2.py')
 
-
     def test_explicit_glob(self):
         """
         Can explicit notebook names be used and then a matching search pattern?
@@ -223,7 +219,6 @@ class TestNbConvertApp(TestsBase):
             assert os.path.isfile('notebook1.py')
             assert os.path.isfile('notebook2.py')
 
-
     def test_default_config(self):
         """
         Does the default config work?
@@ -233,10 +228,9 @@ class TestNbConvertApp(TestsBase):
             assert os.path.isfile('notebook1.py')
             assert not os.path.isfile('notebook2.py')
 
-
     def test_override_config(self):
         """
-        Can the default config be overriden?
+        Can the default config be overridden?
         """
         with self.create_temp_cwd(['notebook*.ipynb',
                                    'jupyter_nbconvert_config.py',
@@ -254,7 +248,7 @@ class TestNbConvertApp(TestsBase):
             self.nbconvert('--log-level 0 --to Python nb1_*')
             assert os.path.isfile(u'nb1_análisis.py')
 
-    @dec.onlyif_cmds_exist('xelatex', 'pandoc')
+    @onlyif_cmds_exist('xelatex', 'pandoc')
     def test_filename_accent_pdf(self):
         """
         Generate PDFs if notebooks have an accent in their name?
@@ -306,10 +300,10 @@ class TestNbConvertApp(TestsBase):
             assert os.path.isfile('empty.ipynb')
             assert not os.path.isfile('empty.nbconvert.ipynb')
             assert not os.path.isfile('empty.html')
-    
+
     def test_no_prompt(self):
         """
-        Verify that the notebook is converted in place
+        Verify that the html has no prompts when given --no-prompt.
         """
         with self.create_temp_cwd(["notebook1.ipynb"]):
             self.nbconvert('notebook1.ipynb --log-level 0 --no-prompt --to html')
@@ -322,10 +316,62 @@ class TestNbConvertApp(TestsBase):
             assert os.path.isfile('notebook1.html')
             with open("notebook1.html",'r') as f:
                 text2 = f.read()
-                print(text2)
                 assert "In&nbsp;[" in text2
                 assert "Out[" in text2
 
+    def test_cell_tag_output(self):
+        """
+        Verify that the html has tags in cell attributes if they exist.
+        """
+        with self.create_temp_cwd(["notebook_tags.ipynb"]):
+            self.nbconvert('notebook_tags.ipynb --log-level 0 --to html')
+            assert os.path.isfile('notebook_tags.html')
+            with open("notebook_tags.html",'r') as f:
+                text = f.read()
+                assert 'code_cell rendered celltag_mycelltag celltag_mysecondcelltag">' in text
+                assert 'code_cell rendered">' in text    
+                assert 'text_cell rendered celltag_mymarkdowncelltag">' in text
+                assert 'text_cell rendered">' in text    
+            
+                
+    def test_no_input(self):
+        """
+        Verify that the html has no input when given --no-input.
+        """
+        with self.create_temp_cwd(["notebook1.ipynb"]):
+            self.nbconvert('notebook1.ipynb --log-level 0 --no-input --to html')
+            assert os.path.isfile('notebook1.html')
+            with open("notebook1.html",'r') as f:
+                text = f.read()
+                assert "In&nbsp;[" not in text
+                assert "Out[" not in text
+                assert ('<span class="n">x</span>'
+                        '<span class="p">,</span>'
+                        '<span class="n">y</span>'
+                        '<span class="p">,</span>'
+                        '<span class="n">z</span> '
+                        '<span class="o">=</span> '
+                        '<span class="n">symbols</span>'
+                        '<span class="p">(</span>'
+                        '<span class="s1">&#39;x y z&#39;</span>'
+                        '<span class="p">)</span>') not in text
+            self.nbconvert('notebook1.ipynb --log-level 0 --to html')
+            assert os.path.isfile('notebook1.html')
+            with open("notebook1.html",'r') as f:
+                text2 = f.read()
+                assert "In&nbsp;[" in text2
+                assert "Out[" in text2
+                assert ('<span class="n">x</span>'
+                        '<span class="p">,</span>'
+                        '<span class="n">y</span>'
+                        '<span class="p">,</span>'
+                        '<span class="n">z</span> '
+                        '<span class="o">=</span> '
+                        '<span class="n">symbols</span>'
+                        '<span class="p">(</span>'
+                        '<span class="s1">&#39;x y z&#39;</span>'
+                        '<span class="p">)</span>') in text2
+
     def test_allow_errors(self):
         """
         Verify that conversion is aborted with '--execute' if an error is
@@ -382,7 +428,7 @@ class TestNbConvertApp(TestsBase):
             output2, _ = self.nbconvert('--to markdown --stdout notebook_jl.ipynb')
             assert '```julia' in output2  # shouldn't have language
             assert "```" in output2  # but should also plain ``` to close cell
-    
+
     def test_convert_from_stdin_to_stdout(self):
         """
         Verify that conversion can be done via stdin to stdout
@@ -408,8 +454,7 @@ class TestNbConvertApp(TestsBase):
                 assert '```python' not in output1 # shouldn't have language
                 assert "```" in output1 # but should have fenced blocks
 
-    @dec.onlyif_cmds_exist('xelatex')
-    @dec.onlyif_cmds_exist('pandoc')
+    @onlyif_cmds_exist('pandoc', 'xelatex')
     def test_linked_images(self):
         """
         Generate PDFs with an image linked in a markdown cell
@@ -418,7 +463,7 @@ class TestNbConvertApp(TestsBase):
             self.nbconvert('--to pdf latex-linked-image.ipynb')
             assert os.path.isfile('latex-linked-image.pdf')
 
-    @dec.onlyif_cmds_exist('pandoc')
+    @onlyif_cmds_exist('pandoc')
     def test_embedded_jpeg(self):
         """
         Verify that latex conversion succeeds
@@ -429,10 +474,10 @@ class TestNbConvertApp(TestsBase):
             self.nbconvert('--to latex notebook4_jpeg.ipynb')
             assert os.path.isfile('notebook4_jpeg.tex')
 
-    @dec.onlyif_cmds_exist('pandoc')
+    @onlyif_cmds_exist('pandoc')
     def test_markdown_display_priority(self):
         """
-        Check to see if markdown conversion embedds PNGs,
+        Check to see if markdown conversion embeds PNGs,
         even if an (unsupported) PDF is present.
         """
         with self.create_temp_cwd(['markdown_display_priority.ipynb']):
@@ -444,7 +489,7 @@ class TestNbConvertApp(TestsBase):
                 assert ("markdown_display_priority_files/"
                         "markdown_display_priority_0_1.png") in markdown_output
 
-    @dec.onlyif_cmds_exist('pandoc')
+    @onlyif_cmds_exist('pandoc')
     def test_write_figures_to_custom_path(self):
         """
         Check if figure files are copied to configured path.
@@ -479,4 +524,3 @@ class TestNbConvertApp(TestsBase):
             self.nbconvert(
                 '--log-level 0 notebook4_jpeg.ipynb --to rst')
             assert fig_exists('notebook4_jpeg_files')
-
